1
0
mirror of https://git.FreeBSD.org/ports.git synced 2025-01-08 06:48:28 +00:00
freebsd-ports/devel/phpsh/files/patch-src_phpsh.php
Ashish SHUKLA 84b2c8f637 phpsh is an interactive shell for php that features readline
history, tab completion, quick access to documentation. It
was developed at Facebook and ironically, is written mostly
in python. It is open source and released under a modified
BSD license.

WWW:	http://phpsh.org/
2011-08-23 17:44:59 +00:00

33 lines
982 B
PHP

$FreeBSD$
--- src/phpsh.php.orig
+++ src/phpsh.php
@@ -10,7 +10,7 @@
// usage: this is only called from phpsh (the python end), as:
// phpsh.php <comm-file> <codebase-mode> [-c]
//
// use '' for default codebase-mode, define others in /etc/phpsh/rc.php
// -c turns off color
// set the TFBENV to script
@@ -46,7 +46,7 @@
if (file_exists($___phpsh___homerc)) {
require_once $___phpsh___homerc;
} else {
- require_once '/etc/phpsh/rc.php';
+ require_once '%%PREFIX%%/etc/phpsh/rc.php';
}
$___phpsh___do_color = true;
@@ -547,7 +547,7 @@
$err_msg =
'Not executing input: Possible call to undefined function '.
$undefd_func."()\n".
- 'See /etc/phpsh/config.sample to disable UndefinedFunctionCheck.';
+ 'See %%PREFIX%%/etc/phpsh/config.sample to disable UndefinedFunctionCheck.';
}
}
if ($err_msg) {
@@ -10,7 +10,7 @@
// phpsh.php <comm-file> <codebase-mode> [-c]
//
-// use '' for default codebase-mode, define others in /etc/phpsh/rc.php
+// use '' for default codebase-mode, define others in %%PREFIX%%/etc/phpsh/rc.php
// -c turns off color
// set the TFBENV to script